@if defined echo (echo %echo% ) else echo off
setlocal

@REM set DEBUG_UPDATE=yes to turn on debugging statements
set DEBUG_UPDATE=no

set LaunchTitle=%0
Echo Start of [ %LaunchTitle% ] launch script.
Echo.

:Wizard
Echo Verifying wizard installer jar:
Echo   [ installer.jar ]
Echo.
IF NOT EXIST "%~dp0installer.jar" GoTo FailWizard
GoTo ParseArgs

:FailWizard
Echo The wizard jar file does not exist.  Exiting.
Echo.
GoTo End

:ParseArgs
set PREREQ_DISABLE_INST=
set PREREQ_DISABLE_UNINST=
set FOR_EFIX=
set RUN_JAVA_HOME=
GoTo ValidateArgs

:ValidateArgs
IF "%1"=="-dpInstall" GoTo SetPrereqInstall
IF "%1"=="-dpUninstall" GoTo SetPrereqUninstall
IF "%1"=="-efixOnly" GoTo SetEFixOnly
IF "%1"=="-skipJDKCopy" GoTo SetExternalJDK

IF "%1"=="" GoTo SetupJDK

IF NOT "%1"=="-usage" Echo Usage error: [ "%1" is an unrecognized argument ]

Echo.
Echo Usage: updateWizard ([ -efixOnly ] [ -dpInstall ] [ -dpUninstall ] [ -skipJDKCopy ] [ -usage ])
Echo.
Echo   efixOnly    - Run the installer in EFix Processing mode only. 
Echo   dpInstall   - Disable install prerequisite error locking.	
Echo   dpUninstall - Disable uninstall prerequisite error locking.
Echo   skipJDKCopy - Run the installer directly from JAVA_HOME.
Echo   usage       - Display syntax help. 
Echo.
GoTo End

:SetEFixOnly
set FOR_EFIX=-W UpdateActionSelect.disablePTFOptions=yes
shift
GoTo ValidateArgs

:SetPrereqInstall
set PREREQ_DISABLE_INST=-W EfixInstallPrereqErrorAction.prereqOverride="yes"
shift
GoTo ValidateArgs  

:SetPrereqUninstall
set PREREQ_DISABLE_UNINST=-W EfixUninstallPrereqError.prereqOverride="yes"
shift
GoTo ValidateArgs

:SetExternalJDK
set RUN_JAVA_HOME=yes
shift
GoTo ValidateArgs

:SetupJDK
set JAVA_TMP=%~dp0java_tmp
IF NOT EXIST "%JAVA_TMP%\bin" GoTo PrepareJDK
IF NOT EXIST "%JAVA_TMP%\bin\java.exe" GoTo PrepareJDK
goto UseLocalJDK

:PrepareJDK
IF NOT "%OS%" == "Windows_NT" GoTo Win9xQuoteStrip
GoTo WinNTQuoteStrip

:Win9XQuoteStrip
@REM FOR %%A IN (%JAVA_HOME%) DO SET NEW_JAVA_HOME=%%A
@REM set JAVA_HOME=%NEW_JAVA_HOME%
@REM IF "%JAVA_HOME%" == "" GoTo CheckSetup
IF "%JAVA_HOME%" == "" GoTo CheckSetup
IF "%RUN_JAVA_HOME%" == "yes" goto RunOffJavaHome

:WinNTQuoteStrip
set JAVA_HOME_TMP=%JAVA_HOME%
set MOD_JAVA_HOME=%JAVA_HOME_TMP:"=%
set NEW_JAVA_HOME=%MOD_JAVA_HOME:"=%
set JAVA_HOME=%NEW_JAVA_HOME%
IF "%JAVA_HOME%" == "=" GoTo CheckSetup
IF "%RUN_JAVA_HOME%" == "yes" goto RunOffJavaHome
goto UseJavaHome

:UseLocalJDK
set JAVA_HOME=%JAVA_TMP%
IF "%DEBUG_UPDATE%" == "yes" Echo Using the local copy of the JDK, made previously, for processing:
IF "%DEBUG_UPDATE%" == "yes" Echo   JAVA_HOME: [ %JAVA_HOME% ]
IF "%DEBUG_UPDATE%" == "yes" Echo.
goto LaunchInstaller

:RunOffJavaHome
Echo No local copy of the JDK will be created.  
Echo The installer will run directly from JAVA_HOME.
Echo.
goto LaunchInstaller

:UseJavaHome
IF "%DEBUG_UPDATE%" == "yes" Echo JAVA_HOME was set.
IF "%DEBUG_UPDATE%" == "yes" Echo   JAVA_HOME: [ %JAVA_HOME% ]
IF "%DEBUG_UPDATE%" == "yes" Echo.
goto TestJDK

:CheckSetup
IF "%DEBUG_UPDATE%" == "yes" Echo JAVA_HOME is not set.
IF "%DEBUG_UPDATE%" == "yes" Echo Attempting to locate setupCmdLine.bat.
IF "%DEBUG_UPDATE%" == "yes" Echo.
IF NOT EXIST "%~dp0..\bin" GoTo FailSetup
IF NOT EXIST "%~dp0..\bin\setupCmdLine.bat" GoTo FailSetup
GoTo CallSetup

:FailSetup
Echo JAVA_HOME must be set before launching the update wizard:
Echo     JAVA_HOME was not set;
Echo     Set JAVA_HOME manually with the install_root/bin/setupCmdLine.bat or setupClient.bat script.
Echo.
Echo (setupCmdLine.bat or setupClient.bat is usually located beneath your
Echo WebSphere Application Server installation, in the 'bin'
Echo directory.)
Echo.
Echo Exiting.
Echo.
GoTo End

:CallSetup
call "%~dp0..\bin\setupCmdLine.bat"
GoTo TestJDK

:TestJDK
IF NOT EXIST "%JAVA_HOME%\bin" GoTo FailJavaHome
IF NOT EXIST "%JAVA_HOME%\bin\java.exe" GoTo FailJavaHome
IF "%RUN_JAVA_HOME%" == "yes" goto RunOffJavaHome
goto CopyJDK

:FailJavaHome
Echo The JDK was not found within the set JAVA_HOME:
Echo   JAVA_HOME: [ %JAVA_HOME%\bin\java.exe ]
Echo.
Echo Exiting.
Echo.
goto End

:CopyJDK
IF NOT "%FOR_EFIX%"=="" goto SkipCopyJDK
IF "%DEBUG_UPDATE%" == "yes" Echo Making local copy of the JDK, which is required
IF "%DEBUG_UPDATE%" == "yes" Echo for PTF processing:
IF "%DEBUG_UPDATE%" == "yes" Echo   JAVA_HOME: [ %JAVA_HOME% ]
IF "%DEBUG_UPDATE%" == "yes" Echo   JAVA_TMP:  [ %JAVA_TMP% ]
IF "%DEBUG_UPDATE%" == "yes" Echo.
IF NOT EXIST "%JAVA_TMP%" MKDIR "%JAVA_TMP%"
IF NOT EXIST "%JAVA_TMP%" GoTo FailedCopyJDK
XCOPY "%JAVA_HOME%" "%JAVA_TMP%" /E /Q
IF NOT EXIST "%JAVA_TMP%\bin" GoTo FailedCopyJDK
IF NOT EXIST "%JAVA_TMP%\bin\java.exe" GoTo FailedCopyJDK
Goto OkCopyJDK

:SkipCopyJDK
Echo EFix processing was selected; no local copy of the
Echo JDK will be created.  PTF processing is disabled.
Echo.
goto LaunchInstaller

:FailedCopyJDK
Echo The JDK could not be copied into the current directory.
Echo JAVA_HOME: [ %JAVA_HOME% ]
Echo JAVA_TMP:  [ %JAVA_TMP% ]
Echo.
Echo Exiting.
Echo.
goto End

:OKCopyJDK
IF "%DEBUG_UPDATE%" == "yes" Echo The JDK was successfully copied.
IF "%DEBUG_UPDATE%" == "yes" Echo.
Set JAVA_HOME=%JAVA_TMP%
GoTo LaunchInstaller


:LaunchInstaller
Echo Launching the update installer wizard.
Echo.
set WindowsLAF=com.sun.java.swing.plaf.windows.WindowsLookAndFeel
set PATH="%JAVA_HOME%"\bin
echo %JAVA_HOME%
echo start /B javaw.exe -Dswing.defaultlaf=%WindowsLAF% -Xmx256m -cp "%~dp0installer.jar;%~dp0lib\extfile.jar" run %FOR_EFIX% %PREREQ_DISABLE_INST% %PREREQ_DISABLE_UNINST%
start /B javaw.exe -Dswing.defaultlaf=%WindowsLAF% -Xmx256m -cp "%~dp0installer.jar;%~dp0lib\extfile.jar" run %FOR_EFIX% %PREREQ_DISABLE_INST% %PREREQ_DISABLE_UNINST%
GoTo End


:End
Echo End of [ %LaunchTitle% ] launch script.
Echo.
endlocal

